# Contributing to ammico

Welcome to `ammico`! Contributions to the package are welcome. Please adhere to the following conventions:

- fork the repository, make your changes, and make sure your changes pass all the tests (Sonarcloud, unit and integration tests, codecoverage limits); then open a Pull Request for your changes. Tag one of `ammico`'s developers for review.
- install and use the pre-commit hooks by running `pre-commit install` in the repository directory so that all your changes adhere to the PEP8 style guide and black code formatting
- make sure to update the documentation if applicable

The tests are located in `ammico/tests`. Unit tests are named `test` following an underscore and the name of the module; inside the unit test modules, each test function is named `test` followed by an underscore and the name of the function/method that is being tested.

To report bugs and issues, please [open an issue](https://github.com/ssciwr/ammico/issues) describing what you did, what you expected to happen, and what actually happened. Please provide information about the environment as well as OS.

For any questions and comments, feel free to post to our [Discussions forum]((https://github.com/ssciwr/AMMICO/discussions/151)).

**Thank you for contributing to `ammico`!**

## Templates
### Template for pull requests

- issues that are addressed by this PR: [*For example, this closes #33 or this addresses #29*]

- changes that were made: [*For example, updated version of dependencies or added a file type for input reading*]

- if applicable: Follow-up work that is required

### Template for bug report

- what I did:

- what I expected:

- what actually happened:

- Python version and environment:

- Operating system:
